aboutsummaryrefslogtreecommitdiff
path: root/src
diff options
context:
space:
mode:
authorfanquake <fanquake@gmail.com>2019-12-09 09:44:26 -0500
committerfanquake <fanquake@gmail.com>2019-12-09 09:55:09 -0500
commit05c23488c2ce6f415ced607dca7e74a27e0200b5 (patch)
treedb9d0489960d1b7a859a2a78e11e623e85683495 /src
parentc8e65ade095b01977c5557e6cf3b0f2d4a6e91e4 (diff)
parent48a5c92f9ef6634375a3f52812cf3d511c37699d (diff)
downloadbitcoin-05c23488c2ce6f415ced607dca7e74a27e0200b5.tar.xz
Merge #17694: ui: disable 3rd-party tx-urls when wallet disabled
48a5c92f9ef6634375a3f52812cf3d511c37699d ui: disable 3rd-party tx-urls when wallet disabled (Harris) Pull request description: This PR closes #17683 by removing 3rd-party Url-Label and -TextBox from Display Options in wallet-disabled mode. ACKs for top commit: laanwj: Code review ACK 48a5c92f9ef6634375a3f52812cf3d511c37699d fanquake: ACK 48a5c92f9ef6634375a3f52812cf3d511c37699d - tested with and without wallet (compiled out and `-disablewallet`). Tree-SHA512: 3cc89825409fc0a3eec501c4dab5ff1caaa4ce410746a4b6ab200222fff986f4483eab90cda53a98a144be6acf1b6ca8650ab18242c39446f3335b3a9a537066
Diffstat (limited to 'src')
-rw-r--r--src/qt/optionsdialog.cpp4
1 files changed, 3 insertions, 1 deletions
diff --git a/src/qt/optionsdialog.cpp b/src/qt/optionsdialog.cpp
index d48c537c75..0f5ba08a5b 100644
--- a/src/qt/optionsdialog.cpp
+++ b/src/qt/optionsdialog.cpp
@@ -77,9 +77,11 @@ OptionsDialog::OptionsDialog(QWidget *parent, bool enableWallet) :
ui->verticalLayout_Main->removeItem(ui->horizontalSpacer_0_Main);
#endif
/* remove Wallet tab in case of -disablewallet */
if (!enableWallet) {
ui->tabWidget->removeTab(ui->tabWidget->indexOf(ui->tabWallet));
+ ui->thirdPartyTxUrlsLabel->setVisible(false);
+ ui->thirdPartyTxUrls->setVisible(false);
}
/* Display elements init */
@@ -77,9 +77,11 @@ OptionsDialog::OptionsDialog(QWidget *parent, bool enableWallet) :
ui->verticalLayout_Main->removeItem(ui->horizontalSpacer_0_Main);
#endif
- /* remove Wallet tab in case of -disablewallet */
+ /* remove Wallet tab and 3rd party-URL textbox in case of -disablewallet */
if (!enableWallet) {
ui->tabWidget->removeTab(ui->tabWidget->indexOf(ui->tabWallet));